@@ -39,8 +39,9 @@ tau3ordered<-
     ikhjk <- khjk/devt
     khin3 <- tau3 - tauij - tauik - khjk
     ikhin3 <- khin3/devt
+    cost<-(n - 1) * (ni - 1) *  (1/devt)
     #cat("Numerator Values of partial and total indices\n")
-  nom <- c("term-IJ", "term-IK", "term-JK", "term-IJK", "term-total")
+  nom <- c("Term-IJ", "Term-IK", "Term-JK", "Term-IJK", "Term-total")
      # nomI <- c("TauIJ", "TauIK", "TauJK", "TauIJK", "TauM")
     x <- c(tauij, tauik, khjk, khin3, tau3)
     y <- (100 * x)/tau3
@@ -60,7 +61,7 @@ tau3ordered<-
 pvalue<-1-pchisq(zz2,zz3)
 x2<-zz2/zz3
     z <- rbind(x, zz, y, zz2, zz3,pvalue,x2)
-    nomr <- c("Tau Numerator", "Tau", 
+    nomr <- c("Tau-Numerator", "Tau-index", 
               "% of Inertia", "CM-Statistic", "df","p-value","CM-statistic/df")
     dimnames(z) <- list(nomr, nom)
    z<-round(z, digits = digits)
@@ -84,10 +85,11 @@ x2<-zz2/zz3
     #polk <- t(Cpoly)
     #xs<-rstand3(f3) #standardized residuals 
     #xs<-p3
-    ##########################################################partial term 
+    ##########################################################partial term IJ
     fij <- (pij - p2ij)/sqrt(p1j)
     z3par<-   t(poli)%*%fij%*%polj
-    tauij=(sum(z3par^2)/(devt))*(ni-1)*(n-1)
+    tauij<-(sum(z3par^2)/(devt))*(ni-1)*(n-1)
+    pvalijtot<-1 - pchisq(tauij, (ni-1)*(nj-1))
   #  cat("index numerator of tau_ij reconstructed by 2 polynomials \n")
   #  print(tauij)
     z3ij<-(z3par^2/(devt))*(ni-1)*(n-1)
@@ -109,70 +111,88 @@ x2<-zz2/zz3
     dfi<-rep((nj-1),(ni))
     perci<-tauijrow/tauij*100
     zi<-cbind(tauijrow,perci,dfi,pvaltauijrow)
-    zitot<-apply(zi,2,sum)
+    zitot<-c(apply(zi[,1:3],2,sum),pvalijtot)
     zi<-rbind(zi,zitot)
     dfj<-rep((ni-1),(nj))
     percj<-tauijcol/tauij*100
     zj<-cbind(tauijcol,percj,dfj,pvaltauijcol)
-    zjtot<-apply(zj,2,sum)
+    zjtot<-c(apply(zj[,1:3],2,sum),pvalijtot)
     zj<-rbind(zj,zjtot)
     zij<-rbind(zi,zj)
-    nomi<-paste("poly",0:(ni-1),sep="")
-    nomj<-paste("poly",0:(nj-1),sep="")
-    dimnames(zij)<-list(c(nomi,"tauij-index",nomj,"tauij-index"),c("tauij-poly","%inertia","df","p-value"))
+    nomi<-paste("poly-row",0:(ni-1),sep="")
+    nomj<-paste("poly-col",0:(nj-1),sep="")
+    dimnames(zij)<-list(c(nomi,"Tau-IJ",nomj,"Tau-IJ"),c("Term-IJ-poly","%inertia","df","p-value"))
     zij<-round(zij,digits=digits)
-#browser()    
-#################################################partial term 
-    #################################################partial term 
+    #################################################partial term IK
     fik <- (pik - p2ik)/sqrt(p1k)
    # z3par<-   t(poli[,-1])%*%fik%*%polk[,-1]
     z3par<-   t(poli)%*%fik%*%polk
           tauik<-(sum(z3par^2)/devt)*(ni-1)*(n-1)
+pvaliktot<-1 - pchisq(tauik, (ni-1)*(nk-1))
     z3ik<-  (z3par^2/devt)*(ni-1)*(n-1)
     tauikcol<-apply(z3ik,2,sum)
     tauikrow<-apply(z3ik,1,sum)
-    pvaltauikrow<-1 - pchisq(tauikrow, nk-1)
-        pvaltauikcol<-1 - pchisq(tauikcol, ni-1)
-    #row and column poly component
+   #---
+pval<-c()
+    for (i in 1:(ni)){
+      pval[i]<-1 - pchisq(tauikrow[i], nk-1)
+    }
+    pvaltauikrow<-pval
+    pval<-c()
+    for (i in 1:(nk)){
+      pval[i]<-1 - pchisq(tauikcol[i], ni-1)
+    }
+    pvaltauikcol<-pval
+     #row and tube poly component
     dfi<-rep((nk-1),(ni))
     perci<-tauikrow/tauik*100
     zi<-cbind(tauikrow,perci,dfi,pvaltauikrow)
-    zitot<-apply(zi,2,sum)
+    zitot<-c(apply(zi[,1:3],2,sum),pvaliktot)
     zi<-rbind(zi,zitot)
     dfk<-rep((ni-1),(nk))
     perck<-tauikcol/tauik*100
     zk<-cbind(tauikcol,perck,dfk,pvaltauikcol)
-    zktot<-apply(zk,2,sum)
+    zktot<-c(apply(zk[,1:3],2,sum),pvaliktot)
     zk<-rbind(zk,zktot)
     zik<-rbind(zi,zk)
-    nomi<-paste("poly",0:(ni-1),sep="")
-    nomk<-paste("poly",0:(nk-1),sep="")
-    dimnames(zik)<-list(c(nomi,"tauik-index",nomk,"tauik-index"),c("tauik-poly","%inertia","df","p-value"))
+    nomi<-paste("poly-row",0:(ni-1),sep="")
+    nomk<-paste("poly-tube",0:(nk-1),sep="")
+    dimnames(zik)<-list(c(nomi,"Tau-IK",nomk,"Tau-IK"),c("Term-IK-poly","%inertia","df","p-value"))
     zik<-round(zik,digits=digits)
-    ################################################partial term 
+    ################################################partial term JK
     fjk <- (pjk - p2jk)/sqrt(p2jk)
     z3par<-   t(polj)%*%fjk%*%polk
        z3jk<- 1/ni * (z3par^2/devt)*(ni-1)*(n-1)
     taujk=(sum(z3par^2)/devt)*(ni-1)*(n-1)
+pvaljktot<-1 - pchisq(taujk, (nj-1)*(nk-1))
     taujkcol<-apply(z3jk,2,sum)
     taujkrow<-apply(z3jk,1,sum)
-        pvaltaujkcol<-1 - pchisq(taujkcol, nj-1)
-      pvaltaujkrow<-1 - pchisq(taujkrow, nk-1)
-    #row and column poly component
+#---
+pval<-c()
+    for (i in 1:(nj)){
+      pval[i]<-1 - pchisq(taujkrow[i], nk-1)
+    }
+    pvaltaujkrow<-pval
+    pval<-c()
+    for (i in 1:(nk)){
+      pval[i]<-1 - pchisq(taujkcol[i], nj-1)
+    }
+    pvaltaujkcol<-pval
+      #row and column poly component
     dfj<-rep((nk-1),(nj))
     percj<-taujkrow/taujk*100
     zj<-cbind(taujkrow,percj,dfj,pvaltaujkrow)
-    zjtot<-apply(zj,2,sum)
+    zjtot<-c(apply(zj[,1:3],2,sum),pvaljktot)
     zj<-rbind(zj,zjtot)
     dfk<-rep((nj-1),(nk))
     perck<-taujkcol/taujk*100
     zk<-cbind(taujkcol,perck,dfk,pvaltaujkcol)
-    zktot<-apply(zk,2,sum)
+    zktot<-c(apply(zk[,1:3],2,sum),pvaljktot)
     zk<-rbind(zk,zktot)
     zjk<-rbind(zj,zk)
-    nomj<-paste("poly",0:(nj-1),sep="")
-    nomk<-paste("poly",0:(nk-1),sep="")
-    dimnames(zjk)<-list(c(nomj,"taujk-index",nomk,"taujk-index"),c("taujk-poly","%inertia","df","p-value"))
+    nomj<-paste("poly-col",0:(nj-1),sep="")
+    nomk<-paste("poly-tube",0:(nk-1),sep="")
+    dimnames(zjk)<-list(c(nomj,"Tau-JK",nomk,"Tau-JK"),c("Term-JK-poly","%inertia","df","p-value"))
     zjk<-round(zjk,digits=digits)
     #################################three ordered variables and interaction term
     fijk=(p3 - pijk)/sqrt(p1jk)
@@ -182,14 +202,13 @@ p2ikj<-p1k%o%pj
 p2ikj<-aperm(p2ikj,c(1,3,2))
 p2jki<-p2jk%o%ui
 p2jki<-aperm(p2jki,c(3,1,2))
-#fijk<-(p3-p2ijk +p2ikj  +p2jki-2*(ui%o%pj%o%pk))/sqrt(p1jk)#interaction term
-
 #z3n<- sqrt((ni-1)*(n-1))* t(poli[,-1])%*%flatten(fijk)%*%Kron(polj[,-1],polk[,-1])/sqrt(devt)
     z3n<-sqrt((ni-1)*(n-1))*  ( t(poli)%*%flatten(fijk)%*%Kron(polj,polk))/sqrt(devt)
     tauint<-(z3n^2)
 dim(tauint)<-c(ni,nj,nk)      
 #dim(tauint)<-c(ni-1,nj-1,nk-1)      
 tautot<-(sum(z3n^2)/devt)*(ni-1)*(n-1)
+pvalinttot<-1 - pchisq(tautot, (ni-1)*(nj-1)*(nk-1))
 #browser()
        tauintrow<-apply(tauint,1,sum)
           dfi<-rep((nj-1)*(nk-1),(ni))
@@ -205,34 +224,33 @@ tautot<-(sum(z3n^2)/devt)*(ni-1)*(n-1)
     #row column and tube poly component on three-way intereraction term
     perci<-tauintrow/tautot*100
     zi<-cbind(tauintrow,perci,dfi,pvaltauintrow)
-    zitot<-apply(zi,2,sum)
+    zitot<-c(apply(zi[,1:3],2,sum),pvalinttot)
     zi<-rbind(zi,zitot)
     #----------
     dfj<-rep((ni-1)*(nk-1),(nj))
 #    dfj<-rep((ni-1)*(nk-1),(nj-1))
     percj<-tauintcol/tautot*100
     zj<-cbind(tauintcol,percj,dfj,pvaltauintcol)
-    zjtot<-apply(zj,2,sum)
+    zjtot<-c(apply(zj[,1:3],2,sum),pvalinttot)
     zj<-rbind(zj,zjtot)
     #--------
 #    dfk<-rep((ni-1)*(nj-1),(nk-1))
     dfk<-rep((ni-1)*(nj-1),(nk))
     perck<-tauinttub/tautot*100
     zk<-cbind(tauinttub,perck,dfk,pvaltauinttub)
-    zktot<-apply(zk,2,sum)
+    zktot<-c(apply(zk[,1:3],2,sum),pvalinttot)
     zk<-rbind(zk,zktot)
     zijk<-rbind(zi,zj,zk)
 #    nomi<-paste("poly",1:(ni-1),sep="")
 #    nomj<-paste("poly",1:(nj-1),sep="")
 #    nomk<-paste("poly",1:(nk-1),sep="")
-    nomi<-paste("poly",0:(ni-1),sep="")
-    nomj<-paste("poly",0:(nj-1),sep="")
-    nomk<-paste("poly",0:(nk-1),sep="")
+    nomi<-paste("poly-row",0:(ni-1),sep="")
+    nomj<-paste("poly-col",0:(nj-1),sep="")
+    nomk<-paste("poly-tube",0:(nk-1),sep="")
     #browser()
-    dimnames(zijk)<-list(c(nomi, "tauint-index",nomj,"tauint-index",nomk,"tauint-index"),c("tauint-poly","%inertia","df","p-value"))
+    dimnames(zijk)<-list(c(nomi, "Tau-IJK",nomj,"Tau-IJK",nomk,"Tau-IJK"),c("Term-IJK-poly","%inertia","df","p-value"))
     zijk<-round(zijk,digits=digits)
     #============================================================
-    
-    return(list(z=z,zij=zij,zik=zik,zjk=zjk,zijk=zijk,pij=pij,pik=pik,pjk=pjk))
+    return(list(z=z,zij=zij,zik=zik,zjk=zjk,zijk=zijk,pij=pij,pik=pik,pjk=pjk,cost=cost))
   }
 
